@@ -222,7 +222,7 @@ def main() -> int:
     if args.timeout <= 0:
         parser.error('invalid timeout')
 
-    REDIS = redis.Redis.from_url(args.redis, decode_components=True)
+    REDIS = redis.Redis.from_url(args.redis, decode_components=True)  # type: ignore[call-overload]
     SCPT = REDIS.register_script(SCPT_TEXT)
     with open('logs/clinic.log', 'at', buffering=1) as file:
         date = datetime.datetime.now().ctime()
